==> wayqt-v0.2.0.tar.gz: wayqt-v0.2.0/examples/LayerShellIntegration/QtLayerShellIntegrationPlugin.cpp <==
/**
 * The GPL v3 License
 *
 * Copyright (c) 2023 Marcus Britanicus (https://gitlab.com/marcusbritanicus)
 * Copyright (c) 2023 Victor Tran (https://github.com/vicr123)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * at your option, any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 **/

#include "LayerShellIntegration.hpp"
#include <QtWaylandClient/private/qwaylandshellintegrationplugin_p.h>

class QtLayerShellIntegrationPlugin : public QtWaylandClient::QWaylandShellIntegrationPlugin {
    Q_OBJECT
    Q_PLUGIN_METADATA( IID QWaylandShellIntegrationFactoryInterface_iid FILE "LayerShellPlugin.json" )

    public:
        QtLayerShellIntegrationPlugin() {
            /** Nothing as yet */
        }

        QtWaylandClient::QWaylandShellIntegration *create( const QString& key, const QStringList& paramList ) override {
            qDebug() << key << paramList;

            if ( key == "desq-layer-shell" ) {
                return new WlrLayerShellIntegration();
            }

            return nullptr;
        }
};

#include "QtLayerShellIntegrationPlugin.moc"

==> wayqt-v0.3.0.tar.gz: wayqt-v0.3.0/examples/LayerShellIntegration/QtLayerShellIntegrationPlugin.cpp <==
/**
 * The GPL v3 License
 *
 * Copyright (c) 2023 Marcus Britanicus (https://gitlab.com/marcusbritanicus)
 * Copyright (c) 2023 Victor Tran (https://github.com/vicr123)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * at your option, any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 **/

#include "LayerShellIntegration.hpp"
#include <QtWaylandClient/private/qwaylandshellintegrationplugin_p.h>

class QtLayerShellIntegrationPlugin : public QtWaylandClient::QWaylandShellIntegrationPlugin {
    Q_OBJECT
    Q_PLUGIN_METADATA( IID QWaylandShellIntegrationFactoryInterface_iid FILE "LayerShellPlugin.json" )

    public:
        QtLayerShellIntegrationPlugin() {
            /** Nothing as yet */
        }

        QtWaylandClient::QWaylandShellIntegration *create( const QString& key, const QStringList& ) override {
            if ( key == "layer-shell-test" ) {
                return new WlrLayerShellIntegration();
            }

            return nullptr;
        }
};

#include "QtLayerShellIntegrationPlugin.moc"
